Enum jsonrpsee_types::FrontToBack [−][src]
pub enum FrontToBack {
Batch(BatchMessage),
Notification(String),
Request(RequestMessage),
Subscribe(SubscriptionMessage),
RegisterNotification(RegisterNotificationMessage),
UnregisterNotification(String),
SubscriptionClosed(SubscriptionId),
}Expand description
Message that the Client can send to the background task.
Variants
Batch(BatchMessage)Send a batch request to the server.
Tuple Fields of Batch
0: BatchMessageNotification(String)Send a notification to the server.
Tuple Fields of Notification
0: StringRequest(RequestMessage)Send a request to the server.
Tuple Fields of Request
Subscribe(SubscriptionMessage)Send a subscription request to the server.
Tuple Fields of Subscribe
RegisterNotification(RegisterNotificationMessage)Register a notification handler
Tuple Fields of RegisterNotification
UnregisterNotification(String)Unregister a notification handler
Tuple Fields of UnregisterNotification
0: StringSubscriptionClosed(SubscriptionId)When a subscription channel is closed, we send this message to the background task to mark it ready for garbage collection.