Enum jsonrpsee_types::error::CallError[][src]

pub enum CallError {
    InvalidParams(Error),
    Failed(Error),
    Custom {
        code: i32,
        message: String,
        data: Option<Box<RawValue>>,
    },
}
Error that occurs when a call failed.

Variants

InvalidParams(Error)

Invalid params in the call.

Tuple Fields of InvalidParams

0: Error
Failed(Error)

The call failed (let jsonrpsee assign default error code and error message).

Tuple Fields of Failed

0: Error
Custom

Custom error with specific JSON-RPC error code, message and data.

Fields of Custom

code: i32

JSON-RPC error code

message: String

Short description of the error.

data: Option<Box<RawValue>>

A primitive or structured value that contains additional information about the error.

Implementations

Create CallError from a generic error.