pub enum SubscriptionAcceptRejectError {
AlreadyCalled,
RemotePeerAborted,
}Expand description
The error returned while accepting or rejecting a subscription.
Variants
AlreadyCalled
The method was already called.
RemotePeerAborted
The remote peer closed the connection or called the unsubscribe method.