Enum jsonrpsee_types::error::CallError[][src]

pub enum CallError {
    InvalidParams,
    Failed(Box<dyn Error + Send + Sync>),
    Custom {
        code: i32,
        message: String,
        data: Option<Box<RawValue>>,
    },
}
Error that occurs when a call failed.

Variants

InvalidParams

Invalid params in the call.

Failed(Box<dyn Error + Send + Sync>)

The call failed (let jsonrpsee assign default error code and error message).

Custom

Custom error with specific JSON-RPC error code, message and data.

Show fields

Fields of Custom

code: i32

JSON-RPC error code

message: String

Short description of the error.

data: Option<Box<RawValue>>

A primitive or structured value that contains additional information about the error.