Struct jsonrpsee_types::error::SubscriptionClosedError [−][src]
pub struct SubscriptionClosedError { /* fields omitted */ }Expand description
Error type with a special subscription_closed field to detect that
a subscription has been closed to distinguish valid items produced
by the server on the subscription stream from an error.